pub struct DatabaseConfig {
pub url: String,
pub host: String,
pub port: u16,
pub name: String,
pub user: String,
pub password: String,
pub max_connections: u32,
pub auto_migrate: bool,
}Fields
url: StringFull connection URL. When empty it is assembled from the parts below.
host: Stringport: u16name: Stringuser: Stringpassword: Stringmax_connections: u32Max pool connections.
auto_migrate: boolRun pending migrations on boot.
Implementations
Sourceimpl DatabaseConfig
impl DatabaseConfig
Sourcepub fn resolved_url(&self) -> String
pub fn resolved_url(&self) -> String
The connection URL, assembled from parts when url was left empty.